==> kubernetes-model-events-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/events/v1/EventBuilder.java <==
package io.fabric8.kubernetes.api.model.events.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class EventBuilder extends io.fabric8.kubernetes.api.model.events.v1.EventFluentImpl<io.fabric8.kubernetes.api.model.events.v1.EventBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.events.v1.Event,io.fabric8.kubernetes.api.model.events.v1.EventBuilder>{
  public EventBuilder() {
    this(false);
  }
  public EventBuilder(java.lang.Boolean validationEnabled) {
    this(new Event(), validationEnabled);
  }
  public EventBuilder(io.fabric8.kubernetes.api.model.events.v1.EventFluent<?> fluent) {
    this(fluent, false);
  }
  public EventBuilder(io.fabric8.kubernetes.api.model.events.v1.EventFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Event(), validationEnabled);
  }
  public EventBuilder(io.fabric8.kubernetes.api.model.events.v1.EventFluent<?> fluent,io.fabric8.kubernetes.api.model.events.v1.Event instance) {
    this(fluent, instance, false);
  }
  public EventBuilder(io.fabric8.kubernetes.api.model.events.v1.EventFluent<?> fluent,io.fabric8.kubernetes.api.model.events.v1.Event instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAction(instance.getAction()); 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withDeprecatedCount(instance.getDeprecatedCount()); 
    fluent.withDeprecatedFirstTimestamp(instance.getDeprecatedFirstTimestamp()); 
    fluent.withDeprecatedLastTimestamp(instance.getDeprecatedLastTimestamp()); 
    fluent.withDeprecatedSource(instance.getDeprecatedSource()); 
    fluent.withEventTime(instance.getEventTime()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withNote(instance.getNote()); 
    fluent.withReason(instance.getReason()); 
    fluent.withRegarding(instance.getRegarding()); 
    fluent.withRelated(instance.getRelated()); 
    fluent.withReportingController(instance.getReportingController()); 
    fluent.withReportingInstance(instance.getReportingInstance()); 
    fluent.withSeries(instance.getSeries()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public EventBuilder(io.fabric8.kubernetes.api.model.events.v1.Event instance) {
    this(instance,false);
  }
  public EventBuilder(io.fabric8.kubernetes.api.model.events.v1.Event instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAction(instance.getAction()); 
    this.withApiVersion(instance.getApiVersion()); 
    this.withDeprecatedCount(instance.getDeprecatedCount()); 
    this.withDeprecatedFirstTimestamp(instance.getDeprecatedFirstTimestamp()); 
    this.withDeprecatedLastTimestamp(instance.getDeprecatedLastTimestamp()); 
    this.withDeprecatedSource(instance.getDeprecatedSource()); 
    this.withEventTime(instance.getEventTime()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withNote(instance.getNote()); 
    this.withReason(instance.getReason()); 
    this.withRegarding(instance.getRegarding()); 
    this.withRelated(instance.getRelated()); 
    this.withReportingController(instance.getReportingController()); 
    this.withReportingInstance(instance.getReportingInstance()); 
    this.withSeries(instance.getSeries()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.events.v1.EventFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.events.v1.Event build() {
    Event buildable = new Event(fluent.getAction(),fluent.getApiVersion(),fluent.getDeprecatedCount(),fluent.getDeprecatedFirstTimestamp(),fluent.getDeprecatedLastTimestamp(),fluent.getDeprecatedSource(),fluent.getEventTime(),fluent.getKind(),fluent.getMetadata(),fluent.getNote(),fluent.getReason(),fluent.getRegarding(),fluent.getRelated(),fluent.getReportingController(),fluent.getReportingInstance(),fluent.getSeries(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EventBuilder that = (EventBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-events-6.1.1-sources.jar: io/fabric8/kubernetes/api/model/events/v1/EventBuilder.java <==
package io.fabric8.kubernetes.api.model.events.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EventBuilder extends EventFluentImpl<EventBuilder> implements VisitableBuilder<Event,EventBuilder>{
  public EventBuilder() {
    this(false);
  }
  public EventBuilder(Boolean validationEnabled) {
    this(new Event(), validationEnabled);
  }
  public EventBuilder(EventFluent<?> fluent) {
    this(fluent, false);
  }
  public EventBuilder(EventFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Event(), validationEnabled);
  }
  public EventBuilder(EventFluent<?> fluent,Event instance) {
    this(fluent, instance, false);
  }
  public EventBuilder(EventFluent<?> fluent,Event instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAction(instance.getAction()); 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withDeprecatedCount(instance.getDeprecatedCount()); 
    fluent.withDeprecatedFirstTimestamp(instance.getDeprecatedFirstTimestamp()); 
    fluent.withDeprecatedLastTimestamp(instance.getDeprecatedLastTimestamp()); 
    fluent.withDeprecatedSource(instance.getDeprecatedSource()); 
    fluent.withEventTime(instance.getEventTime()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withNote(instance.getNote()); 
    fluent.withReason(instance.getReason()); 
    fluent.withRegarding(instance.getRegarding()); 
    fluent.withRelated(instance.getRelated()); 
    fluent.withReportingController(instance.getReportingController()); 
    fluent.withReportingInstance(instance.getReportingInstance()); 
    fluent.withSeries(instance.getSeries()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public EventBuilder(Event instance) {
    this(instance,false);
  }
  public EventBuilder(Event instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAction(instance.getAction()); 
    this.withApiVersion(instance.getApiVersion()); 
    this.withDeprecatedCount(instance.getDeprecatedCount()); 
    this.withDeprecatedFirstTimestamp(instance.getDeprecatedFirstTimestamp()); 
    this.withDeprecatedLastTimestamp(instance.getDeprecatedLastTimestamp()); 
    this.withDeprecatedSource(instance.getDeprecatedSource()); 
    this.withEventTime(instance.getEventTime()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withNote(instance.getNote()); 
    this.withReason(instance.getReason()); 
    this.withRegarding(instance.getRegarding()); 
    this.withRelated(instance.getRelated()); 
    this.withReportingController(instance.getReportingController()); 
    this.withReportingInstance(instance.getReportingInstance()); 
    this.withSeries(instance.getSeries()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  EventFluent<?> fluent;
  Boolean validationEnabled;
  public Event build() {
    Event buildable = new Event(fluent.getAction(),fluent.getApiVersion(),fluent.getDeprecatedCount(),fluent.getDeprecatedFirstTimestamp(),fluent.getDeprecatedLastTimestamp(),fluent.getDeprecatedSource(),fluent.getEventTime(),fluent.getKind(),fluent.getMetadata(),fluent.getNote(),fluent.getReason(),fluent.getRegarding(),fluent.getRelated(),fluent.getReportingController(),fluent.getReportingInstance(),fluent.getSeries(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
